==> deal-facade-1.1.2-sources.jar: com/bxm/spider/deal/facade/model/ContentVo.java <==
package com.bxm.spider.deal.facade.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * <p> 内容 </p>
 *
 * @Author: JandMin
 * @since: 1.0.0
 * @Date: 2018/12/20
 */
@ApiModel(value="返回值",description="返回值对象")
public class ContentVo implements Serializable{
    private static final long serialVersionUID = 1L;
    @ApiModelProperty("id")
    private Long   id;
    @ApiModelProperty("url")
    private String url;
    @ApiModelProperty("图片链接")
    private String imgUrl;
    @ApiModelProperty("标题")
    private String title;
    @ApiModelProperty("内容")
    private String content;
    @ApiModelProperty("频道")
    private String channel;
    @ApiModelProperty("地区")
    private String region;
    @ApiModelProperty("发布时间")
    private Date   deployTime;
    @ApiModelProperty("来源")
    private String source;
    @ApiModelProperty("状态")
    private Integer status;
    @ApiModelProperty("爬取时间")
    private Date dateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public Date getDeployTime() {
        return deployTime;
    }

    public void setDeployTime(Date deployTime) {
        this.deployTime = deployTime;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getDateTime() {
        return dateTime;
    }

    public void setDateTime(Date dateTime) {
        this.dateTime = dateTime;
    }
}

==> deal-facade-1.2.1-20190428.112322-1-sources.jar: com/bxm/spider/deal/facade/model/ContentVo.java <==
package com.bxm.spider.deal.facade.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * <p> 内容 </p>
 *
 * @Author: JandMin
 * @since: 1.0.0
 * @Date: 2018/12/20
 */
@ApiModel(value="返回值",description="返回值对象")
public class ContentVo implements Serializable{
    private static final long serialVersionUID = 1L;
    @ApiModelProperty("id")
    private Long   id;
    @ApiModelProperty("url")
    private String url;
    @ApiModelProperty("图片链接")
    private String imgUrl;
    @ApiModelProperty("标题")
    private String title;
    @ApiModelProperty("内容")
    private String content;
    @ApiModelProperty("频道")
    private String channel;
    @ApiModelProperty("地区")
    private String region;
    @ApiModelProperty("发布时间")
    private String   deployTime;
    @ApiModelProperty("来源")
    private String source;
    @ApiModelProperty("状态")
    private Integer status;
    @ApiModelProperty("爬取时间")
    private String dateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public String getDeployTime() {
        return deployTime;
    }

    public void setDeployTime(String deployTime) {
        this.deployTime = deployTime;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getDateTime() {
        return dateTime;
    }

    public void setDateTime(String dateTime) {
        this.dateTime = dateTime;
    }
}
